@@ -14,7 +14,7 @@ from .download import download
 from .url_handler import epHandler, videourl
 from . import config
 from .query import query
-from .player import mpv
+from .player import start_player
 from .misc import entry, get_anime_info
 from .seasonal import Seasonal
 from .history import history
